@@ -24,6 +24,7 @@ import sys
 import medusa.cassandra_utils
 import medusa.storage
 from medusa.utils import evaluate_boolean
+from medusa.network.hostname_resolver import HostnameResolver
 
 StorageConfig = collections.namedtuple(
     'StorageConfig',
@@ -38,7 +39,7 @@ CassandraConfig = collections.namedtuple(
     ['start_cmd', 'stop_cmd', 'config_file', 'cql_username', 'cql_password', 'check_running', 'is_ccm',
      'sstableloader_bin', 'nodetool_username', 'nodetool_password', 'nodetool_password_file_path', 'nodetool_host',
      'nodetool_port', 'certfile', 'usercert', 'userkey', 'sstableloader_ts', 'sstableloader_tspw',
-     'sstableloader_ks', 'sstableloader_kspw', 'nodetool_ssl', 'resolve_ip_addresses', 'use_sudo']
+     'sstableloader_ks', 'sstableloader_kspw', 'nodetool_ssl', 'resolve_ip_addresses', 'use_sudo', 'nodetool_flags']
 )
 
 SSHConfig = collections.namedtuple(
@@ -53,7 +54,7 @@ ChecksConfig = collections.namedtuple(
 
 MonitoringConfig = collections.namedtuple(
     'MonitoringConfig',
-    ['monitoring_provider']
+    ['monitoring_provider', 'send_backup_name_tag']
 )
 
 MedusaConfig = collections.namedtuple(
@@ -104,7 +105,7 @@ def _build_default_config():
         'host_file_separator': ',',
         'max_backup_age': '0',
         'max_backup_count': '0',
-        'api_profile': 'default',
+        'api_profile': '',
         'transfer_max_bandwidth': '50MB/s',
         'concurrent_transfers': '1',
         'multi_part_upload_threshold': str(100 * 1024 * 1024),
@@ -134,6 +135,7 @@ def _build_default_config():
         'sstableloader_bin': 'sstableloader',
         'resolve_ip_addresses': 'True',
         'use_sudo': 'True',
+        'nodetool_flags': '-Dcom.sun.jndi.rmiURLParsing=legacy'
     }
 
     config['ssh'] = {
@@ -152,7 +154,8 @@ def _build_default_config():
     }
 
     config['monitoring'] = {
-        'monitoring_provider': 'None'
+        'monitoring_provider': 'None',
+        'send_backup_name_tag': 'False'
     }
 
     config['grpc'] = {
@@ -203,17 +206,42 @@ def parse_config(args, config_file):
         if evaluate_boolean(config['cassandra']['use_sudo']):
             logging.warning('Forcing use_sudo to False because Kubernetes mode is enabled')
         config['cassandra']['use_sudo'] = 'False'
+        config['storage']['use_sudo_for_restore'] = 'False'
+        if "POD_IP" in os.environ:
+            config['storage']['fqdn'] = os.environ["POD_IP"]
 
     resolve_ip_addresses = evaluate_boolean(config['cassandra']['resolve_ip_addresses'])
     config.set('cassandra', 'resolve_ip_addresses', 'True' if resolve_ip_addresses else 'False')
+    kubernetes_enabled = evaluate_boolean(config['kubernetes']['enabled'])
+    hostname_resolver = HostnameResolver(resolve_ip_addresses, kubernetes_enabled)
     if config['storage']['fqdn'] == socket.getfqdn() and not resolve_ip_addresses:
         # Use the ip address instead of the fqdn when DNS resolving is turned off
         config['storage']['fqdn'] = socket.gethostbyname(socket.getfqdn())
+    elif config['storage']['fqdn'] == socket.getfqdn():
+        # The FQDN for the local node should comply with the hostname resolving rules.
+        config.set('storage', 'fqdn', hostname_resolver.resolve_fqdn())
 
-    if "CQL_USERNAME" in os.environ:
-        config['cassandra']['cql_username'] = os.environ["CQL_USERNAME"]
-    if "CQL_PASSWORD" in os.environ:
-        config['cassandra']['cql_password'] = os.environ["CQL_PASSWORD"]
+    for config_property in ['cql_username', 'cql_password']:
+        config_property_upper_old = config_property.upper()
+        config_property_upper_new = "MEDUSA_{}".format(config_property.upper())
+        if config_property_upper_old in os.environ:
+            config['cassandra'][config_property] = os.environ[config_property_upper_old]
+            logging.warning('The {} environment variable is deprecated and has been replaced by the {} variable'
+                            .format(config_property_upper_old, config_property_upper_new))
+        if config_property_upper_new in os.environ:
+            config['cassandra'][config_property] = os.environ[config_property_upper_new]
+            logging.warning('Both {0} and {1} are defined in the environment; using the value set in {1}'
+                            .format(config_property_upper_old, config_property_upper_new))
+
+    for config_property in [
+        'nodetool_username',
+        'nodetool_password',
+        'sstableloader_tspw',
+        'sstableloader_kspw'
+    ]:
+        config_property_upper = "MEDUSA_{}".format(config_property.upper())
+        if config_property_upper in os.environ:
+            config['cassandra'][config_property] = os.environ[config_property_upper]
 
     return config
 
